@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
+ * Copyright (C) 1997-2001 Free Software Foundation
  * Copyright (C) 2000, 2001 Eazel, Inc.
  * All rights reserved.
  *
@@ -24,8 +24,14 @@
 #ifndef GNOME_VFS_MIME_H
 #define GNOME_VFS_MIME_H
 
-#include <glib.h>
-#include "gnome-vfs-types.h"
+#include <ctype.h>
+#include <dirent.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <regex.h>
+#include <stdio.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #ifdef __cplusplus
 extern "C" {
