@@ -37,6 +37,7 @@
 #include <limits.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <utime.h>
 #include <string.h>
@@ -46,6 +47,9 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-module-shared.h>
 #include <libgnomevfs/gnome-vfs-result.h>
+#include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-cancellation.h>
+#include <libgnomevfs/gnome-vfs-context.h>
 
 /* this is a work-around for some systems, which define these 
  * symbols without guards
@@ -86,8 +90,8 @@ G_LOCK_DEFINE_STATIC (server_connection_list);
 
 /* Module entry points. */
 GnomeVFSMethod *vfs_module_init     (const char     *method_name,
-				     const char     *args);
-void            vfs_module_shutdown (GnomeVFSMethod *method);
+				        const char     *args);
+void            vfs_module_shutdown  (GnomeVFSMethod *method);
 
 static GnomeVFSResult
 nfs_get_attr(GnomeVFSURI *uri, NfsServerConnection *conn, GnomeVFSFileInfo *info);
@@ -125,6 +129,10 @@ nfs_clnt_call(CLIENT *clnt, u_long procnum, xdrproc_t inproc, char *in,
 		if (rv == RPC_SUCCESS && !*success) {
 			/* all good, break from this loop */
 			break;
+#ifdef ECOMM
+/* no ECOMM on FreeBSD.
+ * You may want to check that with autoconf or leave like that.
+ */
 		} else if (*success == ECOMM) {
 			/* this error is evil, only way around it is 
 			   to destroy the RPC connection and start over
@@ -134,11 +142,12 @@ nfs_clnt_call(CLIENT *clnt, u_long procnum, xdrproc_t inproc, char *in,
 			 * do something intelligent, don't just fail out
 			 * FIXME
 			 */
+#endif
 		} else if ((rv == RPC_CANTSEND) || /* can't send */ 
 			   (rv == RPC_CANTRECV) || /* can't receive */
 			   (rv == RPC_TIMEDOUT) || /* timed out */
 			   (rv == RPC_SYSTEMERROR) || /* generic other problem at server */
-			   (rv == RPC_RPCBFAILURE) || /* portmapper failed in its call */
+			   (rv == RPC_PMAPFAILURE) || /* portmapper failed in its call */
 			   (rv == RPC_CANTDECODEARGS) || /* can't decode arguments */
 			   (rv == RPC_CANTENCODEARGS) || /* can't encode arguments */
 			   (rv == RPC_CANTDECODERES) || /* can't decored results */
@@ -1731,6 +1740,7 @@ nfs_hash_foreach (gpointer key, gpointer value, gpointer user_data)
 
 
 static GnomeVFSMethod method = {
+	sizeof (GnomeVFSMethod),
 	do_open,
 	do_create,
 	do_close,
